/*************************************<+>*************************************
 *****************************************************************************
 **
 **   File:        ResConvert.c
 **
 **   Project:     X Widgets
 **
 **   Description: Contains a function to register all of the resource
 **                type converters used within Xw and the converter
 **                routines.
 **
 *****************************************************************************
 **   
 **   Copyright (c) 1988 by Hewlett-Packard Company
 **   Copyright (c) 1988 by the Massachusetts Institute of Technology
 **   
 **   Permission to use, copy, modify, and distribute this software 
 **   and its documentation for any purpose and without fee is hereby 
 **   granted, provided that the above copyright notice appear in all 
 **   copies and that both that copyright notice and this permission 
 **   notice appear in supporting documentation, and that the names of 
 **   Hewlett-Packard or  M.I.T.  not be used in advertising or publicity 
 **   pertaining to distribution of the software without specific, written 
 **   prior permission.
 **   
 *****************************************************************************
 *************************************<+>*************************************/


#include <stdio.h>
#include <string.h>
#include <ctype.h>
#include <X11/Xlib.h>
#include <X11/IntrinsicP.h>
#include <X11/Intrinsic.h>
#include <Xw/Xw.h>
#include <Xw/XwP.h>
#include <Xw/TextEdit.h>
#include <X11/StringDefs.h>



static void _XwCvtStringToTraversalType (
#if NeedFunctionPrototypes
    XrmValue *,
    Cardinal,
    XrmValue *,
    XrmValue *
#endif
);

static void _XwCvtStringToSelectionStyle (
#if NeedFunctionPrototypes
    XrmValue *,
    Cardinal,
    XrmValue *,
    XrmValue *
#endif
);

static void _XwCvtStringToSelectionMethod (
#if NeedFunctionPrototypes
    XrmValue *,
    Cardinal,
    XrmValue *,
    XrmValue *
#endif
);

static void _XwCvtStringToSelectionBias (
#if NeedFunctionPrototypes
    XrmValue *,
    Cardinal,
    XrmValue *,
    XrmValue *
#endif
);

static void _XwCvtStringToElementHighlight (
#if NeedFunctionPrototypes
    XrmValue *,
    Cardinal,
    XrmValue *,
    XrmValue *
#endif
);

static void _XwCvtStringToDestroyMode (
#if NeedFunctionPrototypes
    XrmValue *,
    Cardinal,
    XrmValue *,
    XrmValue *
#endif
);

static void _XwCvtStringToLabelLocation (
#if NeedFunctionPrototypes
    XrmValue *,
    Cardinal,
    XrmValue *,
    XrmValue *
#endif
);

static void _XwCvtStringToRowColMode (
#if NeedFunctionPrototypes
    XrmValue *,
    Cardinal,
    XrmValue *,
    XrmValue *
#endif
);

static void _XwCvtStringToLayoutPolicy (
#if NeedFunctionPrototypes
    XrmValue *,
    Cardinal,
    XrmValue *,
    XrmValue *
#endif
);

static Boolean StringsAreEqual (
#if NeedFunctionPrototypes
    char *,
    char *
#endif
);

static void _XwCvtStringToHighlightStyle (
#if NeedFunctionPrototypes
    XrmValue *,
    Cardinal,
    XrmValue *,
    XrmValue *
#endif
);

static void _XwCvtStringToTileType (
#if NeedFunctionPrototypes
    XrmValue *,
    Cardinal,
    XrmValue *,
    XrmValue *
#endif
);

static void _XwCvtStringToSlideOrientation (
#if NeedFunctionPrototypes
    XrmValue *,
    Cardinal,
    XrmValue *,
    XrmValue *
#endif
);

static void _XwCvtStringToArrowDirection (
#if NeedFunctionPrototypes
    XrmValue *,
    Cardinal,
    XrmValue *,
    XrmValue *
#endif
);

static void _XwCvtStringToAlignment (
#if NeedFunctionPrototypes
    XrmValue *,
    Cardinal,
    XrmValue *,
    XrmValue *
#endif
);

static void _XwCvtStringToWidgetType (
#if NeedFunctionPrototypes
    XrmValue *,
    Cardinal,
    XrmValue *,
    XrmValue *
#endif
);

static void _XwCvtStringToLayoutType (
#if NeedFunctionPrototypes
    XrmValue *,
    Cardinal,
    XrmValue *,
    XrmValue *
#endif
);

static void _XwCvtStringToSeparatorType (
#if NeedFunctionPrototypes
    XrmValue *,
    Cardinal,
    XrmValue *,
    XrmValue *
#endif
);

static void _XwCvtStringToGravity (
#if NeedFunctionPrototypes
    XrmValue *,
    Cardinal,
    XrmValue *,
    XrmValue *
#endif
);

static void _XwCvtStringToTitleType (
#if NeedFunctionPrototypes
    XrmValuePtr,
    Cardinal *,
    XrmValuePtr,
    XrmValuePtr
#endif
);

static void _XwCvtStringToLabelType (
#if NeedFunctionPrototypes
    XrmValuePtr,
    Cardinal *,
    XrmValuePtr,
    XrmValuePtr
#endif
);

static void _XwCvtStringToTitlePositionType (
#if NeedFunctionPrototypes
    XrmValuePtr,
    Cardinal *,
    XrmValuePtr,
    XrmValuePtr
#endif
);

static void SetConverter (
#if NeedFunctionPrototypes
    XrmValuePtr,
    XrmValuePtr,
    int
#endif
);

static void CvtStringToEditMode (
#if NeedFunctionPrototypes
    XrmValuePtr *,
    Cardinal *,
    XrmValuePtr,
    XrmValuePtr
#endif
);

static void CvtStringToSourceType (
#if NeedFunctionPrototypes
    XrmValuePtr *,
    Cardinal *,
    XrmValuePtr,
    XrmValuePtr
#endif
);

static void CvtStringToWrap (
#if NeedFunctionPrototypes
    XrmValuePtr *,
    Cardinal *,
    XrmValuePtr,
    XrmValuePtr
#endif
);

static void CvtStringToWrapForm (
#if NeedFunctionPrototypes
    XrmValuePtr *,
    Cardinal *,
    XrmValuePtr,
    XrmValuePtr
#endif
);

static void CvtStringToWrapBreak (
#if NeedFunctionPrototypes
    XrmValuePtr *,
    Cardinal *,
    XrmValuePtr,
    XrmValuePtr
#endif
);

static void CvtStringToScroll (
#if NeedFunctionPrototypes
    XrmValuePtr *,
    Cardinal *,
    XrmValuePtr,
    XrmValuePtr
#endif
);

static void CvtStringToGrow (
#if NeedFunctionPrototypes
    XrmValuePtr *,
    Cardinal *,
    XrmValuePtr,
    XrmValuePtr
#endif
);

typedef struct {
  unsigned char *string;
  int value;
} XwSetValuePair;

#define NUMVALUESETS            7
#define XwEditTypeValueSetNum   0
#define XwSourceTypeValueSetNum 1
#define XwWrapValueSetNum       2
#define XwWrapFormValueSetNum   3  
#define XwWrapBreakValueSetNum  4
#define XwScrollValueSetNum     5
#define XwGrowValueSetNum       6

static XwSetValuePair XwEditTypeValueSet[] =
    { {(unsigned char *)"edit",   (int) XwtextEdit},
      {(unsigned char *)"append", (int) XwtextAppend},
      {(unsigned char *)"read",   (int) XwtextRead},
      {	NULL, 0 }
    };
static XwSetValuePair XwSourceTypeValueSet[] =
    { {(unsigned char *)"stringsrc",   (int) XwstringSrc},
      {(unsigned char *)"disksrc",     (int) XwdiskSrc},
      {(unsigned char *)"userdefined", (int) XwprogDefinedSrc},
      {	NULL, 0 }
    };
static XwSetValuePair XwWrapValueSet[] =
    { {(unsigned char *)"wrapoff",     (int) XwWrapOff},
      {(unsigned char *)"softwrap",    (int) XwSoftWrap},
      {(unsigned char *)"hardwrap",    (int) XwHardWrap},
      {	NULL, 0 }
    };
static XwSetValuePair XwWrapFormValueSet[] =
    { {(unsigned char *)"sourceform",  (int) XwSourceForm},
      {(unsigned char *)"displayform", (int) XwDisplayForm},
      {	NULL, 0 }
    };
static XwSetValuePair XwWrapBreakValueSet[] =
    { {(unsigned char *)"wrapany",        (int) XwWrapAny},
      {(unsigned char *)"wrapwhitespace", (int) XwWrapWhiteSpace},
      {	NULL, 0 }
    };
static XwSetValuePair XwScrollValueSet[] =
    { {(unsigned char *)"autoscrolloff",        (int) XwAutoScrollOff},
      {(unsigned char *)"autoscrollvertical",   (int) XwAutoScrollVertical},
      {(unsigned char *)"autoscrollhorizontal", (int) XwAutoScrollHorizontal},
      {(unsigned char *)"autoscrollboth",       (int) XwAutoScrollBoth},
      {	NULL, 0 }
    };
static XwSetValuePair XwGrowValueSet[] =
    { {(unsigned char *)"growoff",        (int) XwGrowOff},
      {(unsigned char *)"growhorizontal", (int) XwGrowHorizontal},
      {(unsigned char *)"growvertical",   (int) XwGrowVertical},
      {(unsigned char *)"growboth",       (int) XwGrowBoth},
      {	NULL, 0 }
    };

XwSetValuePair *_XwResConvertvaluepairsets[NUMVALUESETS];
Boolean _XwResConvertregistered = False;

/************************************************************************
 *
 *  XwRegisterConverters
 *	Register all of the Xw resource type converters.  Retain a
 *	flag indicating whether the converters have already been
 *	registered.
 *
 ************************************************************************/

void
XwRegisterConverters ()
{
   if (!_XwResConvertregistered)
   {
      XtAddConverter (XtRString, XwRTraversalType,
                      (XtConverter) _XwCvtStringToTraversalType, NULL, 0);
      XtAddConverter (XtRString, XwRRCMode,
		      (XtConverter) _XwCvtStringToRowColMode, NULL, 0);
      XtAddConverter (XtRString, XwRLayout,
		      (XtConverter) _XwCvtStringToLayoutPolicy, NULL, 0);
      XtAddConverter (XtRString, XwRHighlightStyle,
		      (XtConverter) _XwCvtStringToHighlightStyle, NULL, 0);
      XtAddConverter (XtRString, XwRTileType,
		      (XtConverter) _XwCvtStringToTileType, NULL, 0);
      XtAddConverter (XtRString, XwRArrowDirection,
                      (XtConverter) _XwCvtStringToArrowDirection, NULL, 0);
      XtAddConverter (XtRString, XwRLabelLocation,
                      (XtConverter) _XwCvtStringToLabelLocation, NULL, 0);
      XtAddConverter (XtRString, XwRSlideOrientation,
                      (XtConverter) _XwCvtStringToSlideOrientation, NULL, 0);
      XtAddConverter (XtRString, XwRAlignment,
                      (XtConverter) _XwCvtStringToAlignment, NULL, 0);
      XtAddConverter (XtRString, XwRWidgetType,
                      (XtConverter) _XwCvtStringToWidgetType, NULL, 0);
      XtAddConverter (XtRString, XwRLayoutType,
                      (XtConverter) _XwCvtStringToLayoutType, NULL, 0);
      XtAddConverter (XtRString, XwRSeparatorType,
                      (XtConverter) _XwCvtStringToSeparatorType, NULL, 0);
      XtAddConverter (XtRString, XwRSelectionMethod,
		      (XtConverter) _XwCvtStringToSelectionMethod, NULL,0);
      XtAddConverter (XtRString, XwRSelectionStyle,
		      (XtConverter) _XwCvtStringToSelectionStyle, NULL,0);
      XtAddConverter (XtRString, XwRSelectionBias,
		      (XtConverter) _XwCvtStringToSelectionBias, NULL,0);
      XtAddConverter (XtRString, XwRElementHighlight,
		      (XtConverter) _XwCvtStringToElementHighlight, NULL,0);
      XtAddConverter (XtRString, XwRDestroyMode,
		      (XtConverter) _XwCvtStringToDestroyMode, NULL,0);
      XtAddConverter (XtRString, XwRGravity,
		      (XtConverter) _XwCvtStringToGravity, NULL,0);
      XtAddConverter (XtRString, XwRTitlePositionType,
                      _XwCvtStringToTitlePositionType, NULL, 0);
      XtAddConverter (XtRString, XwRTitleType, _XwCvtStringToTitleType, 
                      NULL, 0);
      XtAddConverter (XtRString, XwRLabelType, _XwCvtStringToLabelType, 
                      NULL, 0);

  _XwResConvertvaluepairsets[XwEditTypeValueSetNum] = XwEditTypeValueSet;  
  _XwResConvertvaluepairsets[XwSourceTypeValueSetNum] = XwSourceTypeValueSet;
  _XwResConvertvaluepairsets[XwWrapValueSetNum] = XwWrapValueSet;
  _XwResConvertvaluepairsets[XwWrapFormValueSetNum] = XwWrapFormValueSet;
  _XwResConvertvaluepairsets[XwWrapBreakValueSetNum] = XwWrapBreakValueSet;
  _XwResConvertvaluepairsets[XwScrollValueSetNum] = XwScrollValueSet;
  _XwResConvertvaluepairsets[XwGrowValueSetNum] = XwGrowValueSet;

  XtAddConverter(XtRString, XtREditMode, (XtConverter) CvtStringToEditMode, NULL, 0);
  XtAddConverter(XtRString, XwRSourceType, (XtConverter) CvtStringToSourceType, NULL, 0);
  XtAddConverter(XtRString, XwRWrap, (XtConverter) CvtStringToWrap, NULL, 0);
  XtAddConverter(XtRString, XwRWrapBreak, (XtConverter) CvtStringToWrapBreak, NULL, 0);
  XtAddConverter(XtRString, XwRWrapForm, (XtConverter) CvtStringToWrapForm, NULL, 0);
  XtAddConverter(XtRString, XwRScroll, (XtConverter) CvtStringToScroll, NULL, 0);
  XtAddConverter(XtRString, XwRGrow, (XtConverter) CvtStringToGrow, NULL, 0);

  }
   _XwResConvertregistered = True;
}




/************************************************************************
 *
 *  Resource Conversion Functions
 *     The following set of functions are used by the resource
 *     manager to convert the resource types defined for this class.
 *
 ************************************************************************/


/*  Convert a string to a traversal type.  */

static void _XwCvtStringToTraversalType (args, numArgs, fromVal, toVal) 
XrmValue * args;
Cardinal   numArgs;
XrmValue * fromVal;
XrmValue * toVal;

{
   char * in_str = (char *) (fromVal->addr);
   static int i;

   i = XwHIGHLIGHT_OFF;

   if (((*in_str) == 'H') || ((*in_str) == 'h'))
   {
      if (StringsAreEqual (in_str, "highlight_traversal"))
         i = XwHIGHLIGHT_TRAVERSAL;
      else if (StringsAreEqual (in_str, "highlight_enter"))
         i = XwHIGHLIGHT_ENTER;
   }

   (*toVal).size = sizeof (int);
   (*toVal).addr = (caddr_t) &i;
}

/*  Convert a string to a Selection Style.  */

static void _XwCvtStringToSelectionStyle (args, numArgs, fromVal, toVal) 
XrmValue * args;
Cardinal   numArgs;
XrmValue * fromVal;
XrmValue * toVal;

{
   static int i;

   if (StringsAreEqual ("instant", (char *) fromVal -> addr) )
      i = XwINSTANT;
   else if (StringsAreEqual("sticky", (char *) fromVal -> addr))
      i = XwSTICKY;
   else
      i = XwSTICKY;

   (*toVal).size = sizeof (int);
   (*toVal).addr = (caddr_t) &i;
}

/*  Convert a string to a Selection Method.  */

static void _XwCvtStringToSelectionMethod (args, numArgs, fromVal, toVal) 
XrmValue * args;
Cardinal   numArgs;
XrmValue * fromVal;
XrmValue * toVal;

{
   static int i;

   if (StringsAreEqual ("single", (char *) fromVal -> addr))
      i = XwSINGLE;
   else if (StringsAreEqual ("multiple", (char *) fromVal -> addr))
      i = XwMULTIPLE;
   else
      i = XwSINGLE;

   (*toVal).size = sizeof (int);
   (*toVal).addr = (caddr_t) &i;
}

/*  Convert a string to a Selection Bias.  */

static void _XwCvtStringToSelectionBias (args, numArgs, fromVal, toVal) 
XrmValue * args;
Cardinal   numArgs;
XrmValue * fromVal;
XrmValue * toVal;

{
   static int i;

   if (StringsAreEqual ("col_bias", (char *) fromVal -> addr) )
      i = XwCOL_BIAS;
   else if (StringsAreEqual ("row_bias", (char *) fromVal -> addr))
      i = XwROW_BIAS;
   else
      i = XwNO_BIAS;

   (*toVal).size = sizeof (int);
   (*toVal).addr = (caddr_t) &i;
}

/*  Convert a string to a element highlight.  */

static void _XwCvtStringToElementHighlight (args, numArgs, fromVal, toVal) 
XrmValue * args;
Cardinal   numArgs;
XrmValue * fromVal;
XrmValue * toVal;

{
   static int i;

   if (StringsAreEqual ("border", (char *) fromVal -> addr))
      i = XwBORDER;
   else if (StringsAreEqual ("invert", (char *) fromVal -> addr))
      i = XwINVERT;
   else
      i = XwINVERT;

   (*toVal).size = sizeof (int);
   (*toVal).addr = (caddr_t) &i;
}

/*  Convert a string to a destroy mode.  */

static void _XwCvtStringToDestroyMode (args, numArgs, fromVal, toVal) 
XrmValue * args;
Cardinal   numArgs;
XrmValue * fromVal;
XrmValue * toVal;

{
   static int i;

   if (StringsAreEqual ("no_shrink", (char *) fromVal -> addr))
      i = XwNO_SHRINK;
   else if (StringsAreEqual ("shrink_all", (char *) fromVal -> addr))
      i = XwSHRINK_ALL;
   else
      i = XwSHRINK_COLUMN;

   (*toVal).size = sizeof (int);
   (*toVal).addr = (caddr_t) &i;
}

/******************************************************/
/*  Convert a string to a ButtonClass Label Location. */
/******************************************************/
static void _XwCvtStringToLabelLocation (args, numArgs, fromVal, toVal)
XrmValue * args;
Cardinal   numArgs;
XrmValue * fromVal;
XrmValue * toVal;

{
   char * in_str = (char *) (fromVal->addr);
   static int i;

    if (((*in_str)== 'L') || ((*in_str)=='l'))
        {
           if (StringsAreEqual(in_str,"left")) i = XwLEFT;
	}
   else
      i = XwRIGHT;

   (*toVal).size = sizeof (Position);
   (*toVal).addr = (caddr_t) &i;
}



/*****************************************************/
/*  Convert a string to a Row/Column selection type. */
/*****************************************************/
static void _XwCvtStringToRowColMode (args, numArgs, fromVal, toVal)
XrmValue * args;
Cardinal   numArgs;
XrmValue * fromVal;
XrmValue * toVal;

{
   char * in_str = (char *) (fromVal->addr);
   static int i;

    if (((*in_str)== 'O') || ((*in_str)=='o'))
        {
           if (StringsAreEqual(in_str,"one_of_many")) i = XwONE_OF_MANY;
	}
   else
      i = XwN_OF_MANY;

   (*toVal).size = sizeof (int);
   (*toVal).addr = (caddr_t) &i;
}



/********************************************************/
/*  Convert a string to ManagerClass layout mode type.  */
/********************************************************/
static void _XwCvtStringToLayoutPolicy (args, numArgs, fromVal, toVal)
XrmValue * args;
Cardinal   numArgs;
XrmValue * fromVal;
XrmValue * toVal;

{
   char * in_str = (char *) (fromVal->addr);
   static int i;

   i = XwMINIMIZE;

   switch(*in_str)
   {
      case 'I':
      case 'i':
           if (StringsAreEqual(in_str,"ignore")) i = XwIGNORE;
	   break;
	   
      case 'M':
      case 'm':
           if (StringsAreEqual(in_str,"maximize")) i = XwMAXIMIZE;

   }

   (*toVal).size = sizeof (int);
   (*toVal).addr = (caddr_t) &i;
}



static Boolean StringsAreEqual(in_str, test_str)
char *in_str, *test_str;
{
   int i, j;

   for (;;)
   {
      i = *in_str;
      j = *test_str;

      if (isupper(i)) i = tolower(i);
      if (isupper(j)) j = tolower(j);
      if (i != j) return (False);
      if (i == 0) return (True);

      in_str++;
      test_str++;
   }
}   


/*  Convert a string to a highlight type.  */

static void _XwCvtStringToHighlightStyle (args, numArgs, fromVal, toVal)
XrmValue * args;
Cardinal   numArgs;
XrmValue * fromVal;
XrmValue * toVal;

{
   char * in_str = (char *) (fromVal->addr);
   static int i;

   i = XwWIDGET_DEFINED;

   if (((*in_str) == 'P') || ((*in_str) == 'p'))
      if (StringsAreEqual (in_str, "pattern_border"))
         i = XwPATTERN_BORDER;

   (*toVal).size = sizeof (int);
   (*toVal).addr = (caddr_t) &i;
}




/*  Convert a string to an tile type.  */

static void _XwCvtStringToTileType (args, numArgs, fromVal, toVal)
XrmValue * args;
Cardinal   numArgs;
XrmValue * fromVal;
XrmValue * toVal;

{
   char * in_str = (char *) (fromVal->addr);
   static int i;

   i = Xw50_FOREGROUND;

   switch (*in_str)
   {
      case 'F':
      case 'f':
         if (StringsAreEqual (in_str, "foreground")) i = XwFOREGROUND;
      break;

      case 'B':
      case 'b':
         if (StringsAreEqual (in_str, "background")) i = XwBACKGROUND;
      break;

      case '2':
         if (StringsAreEqual (in_str, "25_foreground")) i = Xw25_FOREGROUND;
      break;

      case '5':
         if (StringsAreEqual (in_str, "50_foreground")) i = Xw50_FOREGROUND;
      break;

      case '7':
         if (StringsAreEqual (in_str, "75_foreground")) i = Xw75_FOREGROUND;
      break;

      case 'V':
      case 'v':
         if (StringsAreEqual (in_str, "vertical_tile")) i = XwVERTICAL_TILE;
      break;

      case 'H':
      case 'h':
         if (StringsAreEqual(in_str,"horizontal_tile")) i = XwHORIZONTAL_TILE;
      break;

      case 'S':
      case 's':
         if (StringsAreEqual (in_str, "slant_left")) i = XwSLANT_LEFT;
         else if (StringsAreEqual (in_str, "slant_right")) i = XwSLANT_RIGHT;
      break;
   }


   (*toVal).size = sizeof (int);
   (*toVal).addr = (caddr_t) &i;
}




/*  Convert a string to a slide orientation.  */

static void _XwCvtStringToSlideOrientation (args, numArgs, fromVal, toVal)
XrmValue * args;
Cardinal   numArgs;
XrmValue * fromVal;
XrmValue * toVal;

{
   char * in_str = (char *) (fromVal->addr);
   static int i;

   i = XwVERTICAL;

   if (((*in_str) == 'H') || ((*in_str) == 'h'))
      if (StringsAreEqual (in_str, "horizontal")) i = XwHORIZONTAL;

   (*toVal).size = sizeof (int);
   (*toVal).addr = (caddr_t) &i;
}



/*  Convert a string to an arrow direction.  */

static void _XwCvtStringToArrowDirection (args, numArgs, fromVal, toVal)
XrmValue * args;
Cardinal   numArgs;
XrmValue * fromVal;
XrmValue * toVal;

{
   char * in_str = (char *) (fromVal->addr);
   static int i;

   i = XwARROW_UP;

   if (((*in_str) == 'A') || ((*in_str) == 'a'))
   {
      if (StringsAreEqual (in_str, "arrow_down")) i = XwARROW_DOWN;
      else if (StringsAreEqual (in_str, "arrow_left")) i = XwARROW_LEFT;
      else if (StringsAreEqual (in_str, "arrow_right")) i = XwARROW_RIGHT;
   }

   (*toVal).size = sizeof (int);
   (*toVal).addr = (caddr_t) &i;
}


XwAlignment	_XwResConvertAlign = XwALIGN_LEFT;

/*************************************<->*************************************
 *
 *   static  void _XwCvtStringToAlignment()
 *		Display	*display;
 *		XrmValue	*p_fromVal;
 *		XrmValue	*toVal;
 *
 *	Description:
 *	-----------
 *		This is a type conversion procedure for the resource manager.
 *		converts strings to type XwAlignment.  The conversion is case
 *		insensitive.
 *
 *	Inputs:
 *	------
 *		See "Xlib - C Language X Interface Protocol Version 11"
 *
 *	Outputs:
 *	-------
 *		See "Xlib - C Language X Interface Protocol Version 11"
 *
 *	Procedures Called
 *	-----------------
 *		StringsAreEqual
 *
 *************************************<->***********************************/
static void _XwCvtStringToAlignment(args,num,p_fromVal,toVal)
	XrmValue	*args;
	Cardinal	num;
	XrmValue	*p_fromVal;
	XrmValue	*toVal;
{
	char	*from_str;
	Boolean	match = FALSE;

	from_str = (char *) (p_fromVal->addr);
	toVal->addr = (caddr_t) &_XwResConvertAlign;
	toVal->size = sizeof(XwAlignment);

	switch(*from_str)
	{
		case 'L':
		case 'l':
			if ((match = StringsAreEqual(from_str,"left")) != 0)
				_XwResConvertAlign = XwALIGN_LEFT;
		break;
		case 'C':
		case 'c':
			if ((match = StringsAreEqual(from_str,"center")) != 0)
				_XwResConvertAlign = XwALIGN_CENTER;
		break;
		case 'R':
		case 'r':
			if ((match = StringsAreEqual(from_str,"right")) != 0)
				_XwResConvertAlign = XwALIGN_RIGHT;
		break;
		case 'N':
		case 'n':
			if ((match = StringsAreEqual(from_str,"none")) != 0)
				_XwResConvertAlign = XwALIGN_NONE;
		break;
		default:
			match = FALSE;
		break;
	}

	if(!match)
	{
		toVal->addr = NULL;
		toVal->size = 0;
	}
}


XwWidgetType	_XwResConvertWType = XwUNKNOWN;

/*************************************<->*************************************
 *
 *   static  void _XwCvtStringToWidgetType()
 *		Display	*display;
 *		XrmValue	*p_fromVal;
 *		XrmValue	*toVal;
 *
 *	Description:
 *	-----------
 *		This is a type conversion procedure for the resource manager.
 *		converts strings to type XwWidgetType.  The conversion is case
 *		insensitive.
 *
 *	Inputs:
 *	------
 *		See "Xlib - C Language X Interface Protocol Version 11"
 *
 *	Outputs:
 *	-------
 *		See "Xlib - C Language X Interface Protocol Version 11"
 *
 *	Procedures Called
 *	-----------------
 *		StringsAreEqual
 *
 *************************************<->***********************************/
static void _XwCvtStringToWidgetType(args,num,p_fromVal,toVal)
	XrmValue	*args;
	Cardinal	num;
	XrmValue	*p_fromVal;
	XrmValue	*toVal;
{
	char	*from_str;
	Boolean	match = FALSE;

	from_str = (char *) (p_fromVal->addr);
	toVal->addr = (caddr_t) &_XwResConvertWType;
	toVal->size = sizeof(XwWidgetType);

	switch(*from_str)
	{
		case 'T':
		case 't':
			if ((match = StringsAreEqual(from_str,"title")) != 0)
				_XwResConvertWType = XwTITLE;
		break;
		case 'P':
		case 'p':
			if ((match = StringsAreEqual(from_str,"pulldown")) != 0)
				_XwResConvertWType = XwPULLDOWN;
		break;
		case 'W':
		case 'w':
			if ((match = StringsAreEqual(from_str,"work space")) != 0)
				_XwResConvertWType = XwWORK_SPACE;
		break;
		case 'U':
		case 'u':
			if ((match = StringsAreEqual(from_str,"unknown")) != 0)
				_XwResConvertWType = XwUNKNOWN;
		break;
		default:
			match = FALSE;
		break;
	}

	if(!match)
	{
		toVal->addr = NULL;
		toVal->size = 0;
	}
}


/************************************************************************
 *
 *  _XwCvtStringToLayoutType
 *	Convert a resource string to a layout type.
 *
 ************************************************************************/

static void _XwCvtStringToLayoutType (args, numArgs, fromVal, toVal)
XrmValue * args;
Cardinal   numArgs;
XrmValue * fromVal;
XrmValue * toVal;

{
   char * in_str = (char *) (fromVal->addr);
   static int i;

   i = XwREQUESTED_COLUMNS;

   if (((*in_str) == 'M') || ((*in_str) =='m'))
   {
      if (StringsAreEqual (in_str, "maximum_columns")) i = XwMAXIMUM_COLUMNS;
      else if (StringsAreEqual (in_str, "maximum_unaligned"))
         i = XwMAXIMUM_UNALIGNED;
   }

   (*toVal).size = sizeof (int);
   (*toVal).addr = (caddr_t) &i;
}



/************************************************************************
 *
 *  _XwCvtStringToSeparatorType
 *      Convert a resource string to a menu separator type.
 *
 ************************************************************************/

static void _XwCvtStringToSeparatorType (args, numArgs, fromVal, toVal)
XrmValue * args;
Cardinal   numArgs;
XrmValue * fromVal;
XrmValue * toVal;

{
   char * in_str = (char *) (fromVal->addr);
   static int i;

   i = XwSINGLE_LINE;

   switch(*in_str)
   {
      case 'D':
      case 'd':
         if (StringsAreEqual (in_str, "double_line")) i = XwDOUBLE_LINE;
         else if (StringsAreEqual (in_str, "double_dashed_line"))
            i = XwDOUBLE_DASHED_LINE;
      break;

      case 'S':
      case 's':
         if (StringsAreEqual (in_str, "single_dashed_line"))
            i = XwSINGLE_DASHED_LINE;
      break;

      case 'N':
      case 'n':
         if (StringsAreEqual (in_str, "no_line")) i = XwNO_LINE;
      break;
   }

   (*toVal).size = sizeof (int);
   (*toVal).addr = (caddr_t) &i;
}

int _XwResConvertgravity = CenterGravity;

/************************************************************************
 *
 *  _XwCvtStringToGravity
 *      Convert a resource string to a gravity value.
 *
 ************************************************************************/

static void _XwCvtStringToGravity (args, numArgs, fromVal, toVal)
XrmValue * args;
Cardinal   numArgs;
XrmValue * fromVal;
XrmValue * toVal;

{
	char	*from_str;
	Boolean	match = FALSE;

	from_str = (char *) (fromVal->addr);
	toVal->addr = (caddr_t) &_XwResConvertgravity;
	toVal->size = sizeof(int);

	switch (*from_str)
	{
		case 'N':
		case 'n':
			if ((match = StringsAreEqual(from_str,"NorthGravity")) != 0)
				_XwResConvertgravity = NorthGravity;
			else if ((match = StringsAreEqual(from_str,"NorthWestGravity")) != 0)
				_XwResConvertgravity = NorthWestGravity;
			else if ((match = StringsAreEqual(from_str,"NorthEastGravity")) != 0)
				_XwResConvertgravity = NorthEastGravity;
		break;
		case 'S':
		case 's':
			if ((match = StringsAreEqual(from_str,"SouthGravity")) != 0)
				_XwResConvertgravity = SouthGravity;
			else if ((match = StringsAreEqual(from_str,"SouthWestGravity")) != 0)
				_XwResConvertgravity = SouthWestGravity;
			else if ((match = StringsAreEqual(from_str,"SouthEastGravity")) != 0)
				_XwResConvertgravity = SouthEastGravity;
		break;
		case 'W':
		case 'w':
			if ((match = StringsAreEqual(from_str,"WestGravity")) != 0)
				_XwResConvertgravity = WestGravity;
		break;
		case 'E':
		case 'e':
			if ((match = StringsAreEqual(from_str,"EastGravity")) != 0)
				_XwResConvertgravity = EastGravity;
		break;
		case 'C':
		case 'c':
			if ((match = StringsAreEqual(from_str,"CenterGravity")) != 0)
				_XwResConvertgravity = CenterGravity;
		break;
		default:
			match = FALSE;
		break;
	}

	if(!match)
	{
		toVal->addr = NULL;
		toVal->size = 0;
	}
}


static void _XwCvtStringToTitleType (args, num_args, fromVal, toVal)

   XrmValuePtr args;
   Cardinal  * num_args;
   XrmValuePtr fromVal;
   XrmValuePtr toVal;

{
   static int i;
   String source = (String) fromVal->addr;

   if (source)
   {
      if (strcmp ("string", source) == 0)
         i = XwSTRING;
      else if (strcmp ("image", source) == 0)
         i = XwIMAGE;
      else
      {
         i = XwSTRING;
         XtWarning (
            "MenuPane: Unknown title type specified; using string title");
      }
   }
   else
   {
      i = XwSTRING;
      XtWarning ("MenuPane: Unknown title type specified; using string title");
   }

   (*toVal).size = sizeof(int);
   (*toVal).addr = (caddr_t) &i;
}

static void _XwCvtStringToLabelType (args, num_args, fromVal, toVal)

   XrmValuePtr args;
   Cardinal  * num_args;
   XrmValuePtr fromVal;
   XrmValuePtr toVal;

{
   static int i;

   if (strcmp ("string", (char *) fromVal->addr) == 0)
      i = XwSTRING;
   else if (strcmp ("image", (char *) fromVal->addr) == 0)
      i = XwIMAGE;
   else
   {
      i = XwSTRING;
      XtWarning
	 ("MenuButton: Unknown label type specified; using string label");
   }

   (*toVal).size = sizeof(int);
   (*toVal).addr = (caddr_t) &i;
}

static void _XwCvtStringToTitlePositionType (args, num_args, fromVal, toVal)

   XrmValuePtr args;
   Cardinal * num_args;
   XrmValuePtr fromVal;
   XrmValuePtr toVal;

{
   static int i;
   String source = (char *) fromVal->addr;

   if (source)
   {
      /* Force the comparison to be case insensitive */
      for (i = 0; i < XwStrlen(source); i++)
      {
         if (isupper (source[i]))
            source[i] = tolower(source[i]);
      }

      if (strcmp ("bottom", source) == 0)
         i = XwBOTTOM;
      else if (strcmp ("top", source) == 0)
         i = XwTOP;
      else if (strcmp ("both", source) == 0)
         i = XwTOP | XwBOTTOM;
      else
      {
         i = XwTOP;
         XtWarning ("Cascade: Invalid title position; position set to top");
      }
   }
   else
   {
      i = XwTOP;
      XtWarning ("Cascade: Invalid title position; position set to top");
   }

   (*toVal).size = sizeof(int);
   (*toVal).addr = (caddr_t) &i;
}


/*--------------------------------------------------------------------------+*/
static void SetConverter(fromVal, toVal, setNum)
/*--------------------------------------------------------------------------+*/
     XrmValuePtr fromVal, toVal;
     int setNum;
{
  int j;
  XwSetValuePair *ptr;
  static int value;
  unsigned char *fromstr;

  fromstr = (unsigned char *)fromVal->addr;
  ptr = _XwResConvertvaluepairsets[setNum];
  for(j=0; *ptr[j].string; j++)
    if ((strcmp((char*) ptr[j].string, (char*) fromstr)) == 0) {
      value = ptr[j].value;
      toVal->size = sizeof(int);
      toVal->addr = (caddr_t)&value;
      return;
    };
  toVal->size = 0;
  toVal->addr = NULL;
}

/*--------------------------------------------------------------------------+*/
static void CvtStringToEditMode(args, num_args, fromVal, toVal)
/*--------------------------------------------------------------------------+*/
    XrmValuePtr *args;  /* unused */
    Cardinal    *num_args; /* unused */
    XrmValuePtr	fromVal;
    XrmValuePtr	toVal;
{
  SetConverter(fromVal, toVal, XwEditTypeValueSetNum);
}

/*--------------------------------------------------------------------------+*/
static void CvtStringToSourceType(args, num_args, fromVal, toVal)
/*--------------------------------------------------------------------------+*/
    XrmValuePtr *args;  /* unused */
    Cardinal    *num_args; /* unused */
    XrmValuePtr	fromVal;
    XrmValuePtr	toVal;
{
  SetConverter(fromVal, toVal, XwSourceTypeValueSetNum);
}

/*--------------------------------------------------------------------------+*/
static void CvtStringToWrap(args, num_args, fromVal, toVal)
/*--------------------------------------------------------------------------+*/
    XrmValuePtr *args;  /* unused */
    Cardinal    *num_args; /* unused */
    XrmValuePtr	fromVal;
    XrmValuePtr	toVal;
{
  SetConverter(fromVal, toVal, XwWrapValueSetNum);
}

/*--------------------------------------------------------------------------+*/
static void CvtStringToWrapForm(args, num_args, fromVal, toVal)
/*--------------------------------------------------------------------------+*/
    XrmValuePtr *args;  /* unused */
    Cardinal    *num_args; /* unused */
    XrmValuePtr	fromVal;
    XrmValuePtr	toVal;
{
  SetConverter(fromVal, toVal, XwWrapFormValueSetNum);
}

/*--------------------------------------------------------------------------+*/
static void CvtStringToWrapBreak(args, num_args, fromVal, toVal)
/*--------------------------------------------------------------------------+*/
    XrmValuePtr *args;  /* unused */
    Cardinal    *num_args; /* unused */
    XrmValuePtr	fromVal;
    XrmValuePtr	toVal;
{
  SetConverter(fromVal, toVal, XwWrapBreakValueSetNum);
}

/*--------------------------------------------------------------------------+*/
static void CvtStringToScroll(args, num_args, fromVal, toVal)
/*--------------------------------------------------------------------------+*/
    XrmValuePtr *args;  /* unused */
    Cardinal    *num_args; /* unused */
    XrmValuePtr	fromVal;
    XrmValuePtr	toVal;
{
  SetConverter(fromVal, toVal, XwScrollValueSetNum);
}

/*--------------------------------------------------------------------------+*/
static void CvtStringToGrow(args, num_args, fromVal, toVal)
/*--------------------------------------------------------------------------+*/
    XrmValuePtr *args;  /* unused */
    Cardinal    *num_args; /* unused */
    XrmValuePtr	fromVal;
    XrmValuePtr	toVal;
{
  SetConverter(fromVal, toVal, XwGrowValueSetNum);
}
