.TH XWSTATICRASTER 3X
.SH NAME
XwstaticrasterWidgetClass \- The HP X Widget's static image
widget
.SH SYNOPSIS
#include <X11/StringDefs.h>
.br
#include <X11/Intrinsic.h>
.br
#include <Xw/Xw.h>
.br
#include <Xw/SRaster.h>
.SH CLASSES
The static raster widget is built from the Core, XwPrimitive
and XwSRaster classes.
.PP
The widget class to use when creating a static raster is
XwstaticrasterWidgetClass. The class name is StaticRaster.
.SH DESCRIPTION
The static raster widget provides an uneditable raster
image. As a default, the image is placed in a window that is
exactly the size of the raster (plus the border width). The
image can be dynamically resized. If the window is enlarged
from its original size, the image will be redrawn in the
center of the new window. If the window shrinks below the
size of the raster, the image is clipped on the right and
bottom sides as needed to fit within the new boundries.
.PP
The raster image is provided to the widget in the form of an
XImage data structure. New data can be displayed by
specifing a new XImage structure, or by changing the pointer
to the bitmap data within that structure.
.PP
Callbacks can be attached to the widget to report selection
(XtNselect) and unselection (XtNrelease).  This widget can
be set to respond to Enter and Leave window events by
highlighting and unhighlighting the border.
.SH "NEW RESOURCES"
StaticRaster defines several new resources.  (To reference a
resource in a .Xdefaults file, strip off the XtN from the
resource string.)
.IP "" 14
StaticRaster Resource Set
.ti -16
Resource            Class               Type       Default
.br
.ti -16
__________________________________________________________
.br
.ti -16
XtNsRimage          XtCSRimage          XImage *   NULL
.br
.ti -16
XtNinvertOnSelect   XtCInvertOnSelect   Boolean    TRUE
.br
.ti -16
XtNshowSelected     XtCIShowSelected    Boolean    TRUE
.br
.ti -16
XtNset              XtCSet              Boolean    FALSE
.br
.TP 5
XtNsRimage
.br
This is a pointer to an XImage data structure.
.TP 5
XtNinvertOnSelect
.br
If this resource is TRUE, the raster image will invert
its foreground and background colors when selected, and
return to normal when unselected.
.TP 5
XtNshowSelected
.br
If TRUE, this will cause the image to appear to be
indented when selected, and raised when unselected.
.TP 5
XtNset
.br
This is a Boolean resource which indicates whether the
raster is currently selected (TRUE) or not (FALSE).
.SH "INHERITED RESOURCES"
The following resources are inherited from the named
superclasses:
.IP "" 17
Core Resource Set \-\- CORE(3X)
.ti -22
Name                   Class                  Type             Default
.br
.ti -22
__________________________________________________________________________
.br
.ti -22
XtNancestorSensitive   XtCSenstitive          Boolean          TRUE
.br
.ti -22
XtNx                   XtCPosition            int              0
.br
.ti -22
XtNy                   XtCPosition            int              0
.br
.ti -22
XtNwidth               XtCWidth               int              0
.br
.ti -22
XtNheight              XtCHeight              int              0
.br
.ti -22
XtNdepth               XtCDepth               int              0
.br
.ti -22
XtNbackground          XtCBackground          Pixel            White
.br
.ti -22
XtNbackgroundPixmap    XtCPixmap              Pixmap           Unspecified
.br
.ti -22
XtNborderWidth         XtCBorderWidth         int              1
.br
.ti -22
XtNborderColor         XtCBorderColor         Pixel            Black
.br
.ti -22
XtNborderPixmap        XtCPixmap              Pixmap           Unspecified
.br
.ti -22
XtNsensitive           XtCSensitive           Boolean          TRUE
.br
.ti -22
XtNmappedWhenManaged   XtCMappedWhenManaged   Boolean          TRUE
.br
.ti -22
XtNdestroyCallback     XtCCallback            Pointer          NULL
.br
.ti -22
XtNtranslations        XtCTranslations        XtTranslations   NULL
.br
.IP "" 10
Primitive Resource Set \-\- XWPRIMITIVE(3X)
.ti -15
Name                    Class                   Type      Default
.br
.ti -15
________________________________________________________________________
.br
.ti -15
XtNforeground           XtCForeground           Pixel     Black
.br
.ti -15
XtNbackgroundTile       XtCBackgroundTile       int       background
.br
.ti -15
XtNtraversalType        XtCTraversalType        int       highlight_off
.br
.ti -15
XtNhighlightStyle       XtCHighlightStyle       int       pattern_border
.br
.ti -15
XtNhighlightColor       XtCForeground           Pixel     Black
.br
.ti -15
XtNhighlightTile        XtCHighlightTile        int       50_foreground
.br
.ti -15
XtNhighlightThickness   XtCHighlightThickness   int       0
.br
.ti -15
XtNrecomputeSize        XtCRecomputeSize        Boolean   TRUE
.br
.ti -15
XtNselect               XtCCallback             Pointer   NULL
.br
.ti -15
XtNrelease              XtCCallback             Pointer   NULL
.br
.SH "KEYBOARD TRAVERSAL"
If the XtNtraversalType resource is set to
highlight_traversal (XwHIGHLIGHT_TRAVERSAL in an argument
list) at either create time or during a call to XtSetValues,
the XwPrimitive superclass will automatically augment the
primitive widget's translations to support keyboard
traversal.  Refer to the XwPrimitive man page for a complete
description of these translations.  See the TRANSLATIONS
section in this man page for a description of the
translations local to the static raster widget.
.SH TRANSLATIONS
The static raster is affected by the mouse buttons and
cursor motion.  The default translation set is as follows:
.IP "" 14
<Btn1Down>:      select(),
.br
<Btn1Up>:        release(),
.br
<EnterWindow>:   enter(),
.br
<LeaveWindow>:   leave(),
.SH ACTIONS
.TP 5
select:
.br
Allows an application to be notified of the event via
the callback structure.
.TP 5
release:
.br
Allows an application to be notified of the event via
the callback structure.
.TP 5
enter:
.br
Causes the border to be highlighted if enabled.
.TP 5
leave:
.br
Causes the border to be highlighted if enabled.
.SH NOTES
Error checking on the XImage structure is minimal, so weird
rasters can result from incorrect or incomplete data.
.SH ORIGIN
Hewlett-Packard Company.
.SH "SEE ALSO"
CORE(3X),  XWPRIMITIVE(3X),
.br
Programming With The HP X Widgets,
.br
Programming With Xt Intrinsics,
.br
Programming With Xlib.
